#!/bin/bash

# Configuration
PAPER_URL=https://papermc.io/api/v2/projects/paper

# Enter server directory
cd /papermc

# Determine minecraft version (MC_VERSION) and build number (PAPER_BUILD). If they are set to
# "latest", use PaperMC's API to determine which version and build number is the latest.
if [ ${MC_VERSION} = latest ]
  then
    # Get the latest MC version
    MC_VERSION=$(curl ${PAPER_URL} | jq -r '.versions[-1]') # "-r" is needed because the output has quotes otherwise
fi

PAPER_URL=${PAPER_URL}/versions/${MC_VERSION}
if [ ${PAPER_BUILD} = latest ]
  then
    # Get the latest build
    PAPER_BUILD=$(curl ${PAPER_URL} | jq '.builds[-1]')
fi

# Generate the name of the server JAR file we are about to download from
# the minecraft version and the paper build number we have determined above.
JAR_NAME=paper-${MC_VERSION}-${PAPER_BUILD}.jar

# If the jar is not yet downloaded, download it
if [ ! -e ${JAR_NAME} ]
  then
    # Cleanup older, left-over JAR files
    rm -f *.jar
    # Download the file
    curl ${PAPER_URL}/builds/${PAPER_BUILD}/downloads/${JAR_NAME} --output ${JAR_NAME}
    # Accept EULA
    if [ ! -e eula.txt ]
      then
        java -jar ${JAR_NAME}
        sed -i 's/false/true/g' eula.txt
    fi
fi

# Download base plugins, worlds and configuration by Tobias Müller
if [ ! -d "plugins" ]
 then
   curl -u ${TM_BASE_AUTH} ${TM_BASE_URL} --output initial.tar.gz
   tar -xvzf initial.tar.gz
fi

exec_stop () {
  echo "\n## Recieved SIGINT/SIGTERM; Shutting down container..."
  exit 0
}

while true
  do
    screen -dmS mc java -server -Xms${MC_RAM} -Xmx${MC_RAM} ${JAVA_OPTS} -jar ${JAR_NAME} nogui #Startupbefehl inkl. ENVs vom Dockerfile
	exec screen -x
    screen -wipe # sollte der server mal abstürzen oder sont irgednwie ein fehler auftreten wird damit zombiesessions entfernt.
	trap exec_stop TERM INT # SIGTERM ^C etc abfangen und funktion für gracefull shutdown aufrufen falls aus irgeneinem grund der server nicht der main pid ist
  done
# screen will still be used to enable backup functionality without the need of essentials plugin 
